//
// Copyright (c) 2016, MindFusion LLC - Bulgaria.
//

using System;
using System.Drawing;
using System.Collections;
using System.Windows.Forms;


namespace MindFusion.Scheduling.WinForms.Samples.CS.UnlimitedScrolling
{
	/// <summary>
	/// Summary description for MainForm.
	/// </summary>
	public partial class MainForm : Form
	{
		/// <summary>
		/// Initializes a new instance of the MainForm class.
		/// </summary>
		public MainForm()
		{
			InitializeComponent();

			_appPath = System.IO.Path.GetDirectoryName(Application.ExecutablePath);

			_lbInfo.DocumentText = Properties.Resources.Info;
			_lbInfo.DocumentCompleted += new WebBrowserDocumentCompletedEventHandler(OnDocumentCompleted);
		}

		private void OnDocumentCompleted(object sender, WebBrowserDocumentCompletedEventArgs e)
		{
			if (_lbInfo.Document != null)
			{
				_lbInfo.Document.Click += Document_Click;
				_lbInfo.Document.Body.Style = "font-family: Verdana, Arial, Helvetica, sans-serif; " +
					"font-size: 7.5pt; margin: 2pt; padding: 0pt; background-color: #ffffee; cursor: default;";
			}
		}

		/// <summary>
		/// Handles the Web browser document's Click event.
		/// </summary>
		private void Document_Click(object sender, HtmlElementEventArgs e)
		{
			e.ReturnValue = true;

			HtmlElement pointed = _lbInfo.Document.GetElementFromPoint(e.ClientMousePosition);
			if (pointed == null)
				return;

			if (pointed.TagName.ToLower() == "a")
			{
				string href = pointed.GetAttribute("href").ToLower();
				if (href.StartsWith("help:"))
				{
					string topic = href.Substring(5);
					string helpFile = ResolveHelpPath(_appPath);

					if (System.IO.File.Exists(helpFile))
					{
						Help.ShowHelp(this, helpFile, HelpNavigator.Topic, topic);

						// Prevent link follow
						e.ReturnValue = false;
					}
				}
			}
		}

		private static string ResolveHelpPath(string baseDir)
		{
			string[] helpFiles = new string[]
			{
				"MindFusion.Scheduling.chm",
				"MindFusion WinForms.chm"
			};

			System.IO.DirectoryInfo dirInfo = new System.IO.DirectoryInfo(baseDir);
			int i = 0;
			while (dirInfo != null)
			{
				string helpFile = System.IO.Path.Combine(dirInfo.FullName, helpFiles[i]);
				if (System.IO.File.Exists(helpFile))
					return helpFile;

				i++;
				if (i == helpFiles.Length)
				{
					i = 0;
					dirInfo = dirInfo.Parent;
				}
			}

			return string.Empty;
		}

		private void OnAbout(object sender, System.EventArgs e)
		{
			System.Reflection.Assembly assembly = System.Reflection.Assembly.GetAssembly(
				typeof(MindFusion.Scheduling.WinForms.Calendar));

			if (assembly == null)
				return;

			Type aboutFormType = assembly.GetType(
				"MindFusion.Scheduling.WinForms.AboutForm");

			if (aboutFormType == null)
				return;

			((Form)Activator.CreateInstance(aboutFormType)).ShowDialog(this);
		}

		private void OnExit(object sender, System.EventArgs e)
		{
			this.Close();
		}

		private void _calendar_VScroll(object sender, System.Windows.Forms.ScrollEventArgs e)
		{
			if (e.Type == ScrollEventType.SmallDecrement)
			{
				if (e.NewValue == _calendar.VScrollPos)
				{
					// The decrement doesn't change the scrollbar
					// value, so we must be at the beginning of
					// the view, trying to scroll up
					_calendar.Date -= TimeSpan.FromDays(7);
					_calendar.EndDate -= TimeSpan.FromDays(7);
				}
			}

			if (e.Type == ScrollEventType.SmallIncrement)
			{
				if (e.NewValue == _calendar.VScrollPos)
				{
					// The increment doesn't change the scrollbar
					// value, so we must be at the end of the view,
					// trying to scroll down
					_calendar.Date += TimeSpan.FromDays(7);
					_calendar.EndDate += TimeSpan.FromDays(7);
				}
			}
		}


		private string _appPath;
	}
}
